package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcAssess;
import com.ruoyi.oa.service.ICmcAssessService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 考核表Controller
 * 
 * @author cmc
 * @date 2024-01-09
 */
@RestController
@RequestMapping("/oa/assess")
public class CmcAssessController extends BaseController
{
    @Autowired
    private ICmcAssessService cmcAssessService;

    /**
     * 查询考核表列表
     */
    @PreAuthorize("@ss.hasPermi('oa:assess:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmcAssess cmcAssess)
    {
        startPage();
        List<CmcAssess> list = cmcAssessService.selectCmcAssessList(cmcAssess);
        return getDataTable(list);
    }

    /**
     * 导出考核表列表
     */
    @PreAuthorize("@ss.hasPermi('oa:assess:export')")
    @Log(title = "考核表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcAssess cmcAssess)
    {
        List<CmcAssess> list = cmcAssessService.selectCmcAssessList(cmcAssess);
        ExcelUtil<CmcAssess> util = new ExcelUtil<CmcAssess>(CmcAssess.class);
        util.exportExcel(response, list, "考核表数据");
    }

    /**
     * 获取考核表详细信息
     */
    @PreAuthorize("@ss.hasPermi('oa:assess:query')")
    @GetMapping(value = "/{assessId}")
    public AjaxResult getInfo(@PathVariable("assessId") String assessId)
    {
        return success(cmcAssessService.selectCmcAssessByAssessId(assessId));
    }

    /**
     * 新增考核表
     */
    @PreAuthorize("@ss.hasPermi('oa:assess:add')")
    @Log(title = "考核表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcAssess cmcAssess)
    {
        return toAjax(cmcAssessService.insertCmcAssess(cmcAssess));
    }

    /**
     * 修改考核表
     */
    @PreAuthorize("@ss.hasPermi('oa:assess:edit')")
    @Log(title = "考核表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcAssess cmcAssess)
    {
        return toAjax(cmcAssessService.updateCmcAssess(cmcAssess));
    }

    /**
     * 删除考核表
     */
    @PreAuthorize("@ss.hasPermi('oa:assess:remove')")
    @Log(title = "考核表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{assessIds}")
    public AjaxResult remove(@PathVariable String[] assessIds)
    {
        return toAjax(cmcAssessService.deleteCmcAssessByAssessIds(assessIds));
    }
}
